Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: chrome/browser/android/preferences/pref_service_bridge.h

Issue 2682863002: [Android] Explicitly request all needed runtime permissions. (Closed)
Patch Set: Rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/preferences/pref_service_bridge.h
diff --git a/chrome/browser/android/preferences/pref_service_bridge.h b/chrome/browser/android/preferences/pref_service_bridge.h
index 656a0fece0d6ceaf990dffe96279d0912284badf..fac21f4726fcdd45fd7ec2433cd4d989696744af 100644
--- a/chrome/browser/android/preferences/pref_service_bridge.h
+++ b/chrome/browser/android/preferences/pref_service_bridge.h
@@ -7,6 +7,7 @@
#include <jni.h>
#include <string>
+#include <vector>
#include "components/content_settings/core/common/content_settings.h"
@@ -22,10 +23,11 @@ class PrefServiceBridge {
const std::string& locale,
std::string* accept_languages);
- // Return the corresponding Android permission associated with the
- // ContentSettingsType specified (or an empty string if no permission exists).
- static std::string GetAndroidPermissionForContentSetting(
- ContentSettingsType content_type);
+ // Populate the list of corresponding Android permissions associated with the
+ // ContentSettingsType specified.
+ static void GetAndroidPermissionsForContentSetting(
+ ContentSettingsType content_type,
+ std::vector<std::string>* out);
};
#endif // CHROME_BROWSER_ANDROID_PREFERENCES_PREF_SERVICE_BRIDGE_H_

Powered by Google App Engine
This is Rietveld 408576698